import { useMemo } from 'react';
import cx from "../../../../utils/css/cx.js";
import HeadingThreshold from './HeadingThreshold';
import HeadingDelegates from './HeadingDelegates';
import DelegateRow from './DelegateRow';
import classes from './styles.module.scss';
const cls = cx.merge(classes);
const DelegateTable = function DelegateTable(props) {
  const {
    delegates,
    candidates,
    componentWidth
  } = props;
  const {
    threshold,
    total
  } = delegates;
  const [anyMetThreshold, highestCandidateTotal] = useMemo(() => {
    let amt = false;
    let hct = 0;
    candidates.forEach(c => {
      if (!amt && c.total >= threshold) {
        amt = true;
      }
      hct = Math.max(hct, c.total);
    });
    return [amt, hct];
  }, [candidates, threshold]);
  return <table className={cls('delegate-table')}>
      <thead>
        <tr>
          <th aria-label="Candidate Name" />
          <HeadingDelegates />
          <HeadingThreshold threshold={threshold} anyMetThreshold={anyMetThreshold} />
        </tr>
      </thead>
      <tbody>
        {candidates.map((candidate, idx) => <DelegateRow key={candidate.id} idx={idx} threshold={threshold} anyMetThreshold={anyMetThreshold} highestCandidateTotal={highestCandidateTotal} totalDelegates={total} componentWidth={componentWidth} {...candidate} />)}
      </tbody>
    </table>;
};
export default DelegateTable;