import classnames from 'classnames';
import { useContestCandidateColors, useContestStatus, useCandidateCallStatus, useContestMetadata } from "../../../../hooks/election/index.js";
import getElectionPaletteCssVariables from "../../../../utils/css/getElectionPaletteCssVariables.js";
import { useResultsTableFormatContext } from '../context';
import classes from './styles.module.scss';
const RowWrapper = function RowWrapper(props) {
  const {
    children,
    id,
    candidateId,
    idx
  } = props;
  const {
    size,
    format
  } = useResultsTableFormatContext();
  const candidateColors = useContestCandidateColors(id);
  const palette = candidateColors && candidateColors[candidateId];
  const styleVars = getElectionPaletteCssVariables(palette);
  const candidateStatus = useCandidateCallStatus(id, candidateId);
  const contestStatus = useContestStatus(id);
  const contestHasOutcome = contestStatus.outcome !== 'none';
  const meta = useContestMetadata(id);
  const isUncontested = meta && meta.isUncontested;
  const highlightRow = candidateStatus === 'winner' || candidateStatus === 'runoff';
  const hasBorderBottom = format !== 'condensed' && !!candidateId && !highlightRow;
  return <tr className={classnames(classes.container, classes[format], classes[size], {
    [classes.highlighted]: highlightRow,
    [classes['has-x-padding']]: contestHasOutcome,
    [classes['vote-bar-hidden']]: contestHasOutcome,
    [classes['has-border-bottom']]: hasBorderBottom,
    [classes['is-not-first-row']]: idx !== 0,
    [classes['is-uncontested']]: isUncontested
  })} style={styleVars}>
      {children}
    </tr>;
};
export default RowWrapper;